# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Term-ReadKey
Version:	2.38
Release:	16.%{__distinit}%{__distvers}
Summary:	A perl module for simple terminal control
License:	Copyright only or (GPL+ or Artistic)
URL:		https://metacpan.org/release/TermReadKey
Source0:	https://cpan.metacpan.org/modules/by-module/Term/TermReadKey-%{version}.tar.gz
Patch0:		TermReadKey-configure-c99.patch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	make
BuildRequires:	perl-devel
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(Config)
BuildRequires:	perl(Cwd)
BuildRequires:	perl(ExtUtils::MakeMaker) >= 6.58
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(DynaLoader)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(Fcntl)
BuildRequires:	perl(vars)
# Test Suite
BuildRequires:	expect
BuildRequires:	perl(Test::More)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(Carp)

# Upstream and Red Hat / Fedora packages fail to follow the perl module naming convention
Obsoletes:	perl-TermReadKey < %{version}-%{release}
Provides:	perl-TermReadKey = %{version}-%{release}

# Avoid provides from private objects
%{?perl_default_filter}

%description
Term::ReadKey is a compiled perl module dedicated to providing simple
control over terminal driver modes (cbreak, raw, cooked, etc.),
support for non-blocking reads, if the architecture allows, and some
generalized handy functions for working with terminals. One of the
main goals is to have the functions as portable as possible, so you
can just plug in "use Term::ReadKey" on any architecture and have a
good likelihood of it working.

%prep
%setup -q -n TermReadKey-%{version} 

# Port Configure.pm to C99
%patch -P 0 -p 1

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
find %{buildroot} -type f -name '*.bs' -empty -delete
%{_fixperms} -c %{buildroot}

%check
# Expect is used so that we get a PTY, as if we were in a real terminal
expect -c '
	spawn make test
	expect eof
	exit [lindex [wait] 3]
'

%files
%doc Changes README
%{perl_vendorarch}/auto/Term/
%{perl_vendorarch}/Term/
%{_mandir}/man3/Term::ReadKey.3*

%changelog
* Sun May 14 2023 Paul Howarth <paul@city-fan.org> - 2.38-16
- Port Configure.pm to C99

* Tue May 31 2022 Paul Howarth <paul@city-fan.org> - 2.38-13
- Perl 5.36 rebuild

* Fri May 21 2021 Paul Howarth <paul@city-fan.org> - 2.38-10
- Perl 5.34 rebuild

* Wed Jun 24 2020 Paul Howarth <paul@city-fan.org> - 2.38-7
- Perl 5.32 rebuild

* Thu May 30 2019 Paul Howarth <paul@city-fan.org> - 2.38-3
- Perl 5.30 rebuild

* Sat Jan  5 2019 Paul Howarth <paul@city-fan.org> - 2.38-1
- Update to 2.38
  - Bundle up various changes including:
    - Indexing improvements
    - Makefile improvements for some make utils
    - Various code clean-ups and modernizations

* Wed Jun 27 2018 Paul Howarth <paul@city-fan.org> - 2.37-8
- Perl 5.28 rebuild

* Fri Mar 23 2018 Paul Howarth <paul@city-fan.org> - 2.37-7
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - BR: perl-devel unconditionally

* Fri Oct  7 2016 Paul Howarth <paul@city-fan.org> - 2.37-1
- Update to 2.37
  - Make minimum version of ExtUtils::MakeMaker 6.58
  - Better support parallel builds by making 'dynamic' a dependency of the
    ReadKey.pm
  - Add a 'provides' META section to help indexing
- Update patch for AUTHOR issue
- Reinstate parallel build

* Fri Oct  7 2016 Paul Howarth <paul@city-fan.org> - 2.36-1
- Update to 2.36
  - Add a package declaration to the ReadKey_pm.PL to aid indexing

* Fri Oct  7 2016 Paul Howarth <paul@city-fan.org> - 2.35-1
- Update to 2.35
  - Fix GetTerminalSize() argument handling
  - Fix miniperl build on Win32
  - Remove unused Cwd
  - Fix TAP output
  - Fix warnings in XS file
  - Don't attempt some tests if STDIN is not a terminal
  - Generate ReadKey.pm from ReadKey_pm.PL to expand blockoptions
  - Demand-load Carp
  - Remove unneeded AutoLoader
  - Improve genchars.pl, support make -s silence
  - Improve Makefile.PL: add SIGN, fix pure_site_install, support dual-life,
    fix realclean
- Disable parallel make to avoid build failures
  (https://github.com/jonathanstowe/TermReadKey/issues/23)
- Add patch to fix AUTHOR in Makefile.PL so that EL-6 build can work
  (WARNING: AUTHOR takes a string/number not a ARRAY reference)

* Wed Sep 28 2016 Paul Howarth <paul@city-fan.org> - 2.33-5
- BR: perl-devel and perl-generators where available
- Simplify find commands using -empty and -delete

* Fri Jul  3 2015 Paul Howarth <paul@city-fan.org> - 2.33-1
- Update to 2.33
  - Re-factor tests
  - Fix parallel build (CPAN RT#100932)
- Classify buildreqs by usage
- Run test suite using expect so it'll work in mock

* Mon May 12 2014 Paul Howarth <paul@city-fan.org> - 2.32-1
- Update to 2.32
  - Fix some warnings
- Drop %%defattr, redundant since rpm 4.4

* Sun Oct 27 2013 Paul Howarth <paul@city-fan.org> - 2.31-1
- Update to 2.31
  - Added handling of arrows, page up/down, home/end, insert/delete keys under
    Win32; these keys emit xterm-compatible sequences
  - Works with Term::ReadLine::Perl
- License changed to "Copyright only or (GPL+ or Artistic)"
- Drop upstreamed patches

* Tue Jul 23 2013 Paul Howarth <paul@city-fan.org> - 2.30-19
- Perl 5.18 rebuild

* Tue Jun 12 2012 Paul Howarth <paul@city-fan.org> - 2.30-16
- BR: perl(AutoLoader), perl(Carp), perl(DynaLoader) and perl(Exporter)
- don't need to remove empty directories from the buildroot
- drop support for old distributions prior to FC-3:
  - don't need to define %%{perl_vendorarch}
  - use %%{_fixperms} macro rather than our own chmod incantation
  - use DESTDIR rather than PERL_INSTALL_ROOT

* Wed Jul  6 2011 Paul Howarth <paul@city-fan.org> - 2.30-15
- rebuild with perl 5.14.1 in Rawhide
- nobody else likes macros for commands
- fix dist tag for CentOS 6 and Scientific Linux

* Thu Mar 10 2011 Paul Howarth <paul@city-fan.org> - 2.30-14
- use "make pure_install" rather than "make install"

* Fri Jan  7 2011 Paul Howarth <paul@city-fan.org> - 2.30-13
- reinstate test suite now that mock 1.1.8 fixes tty issues (#510183, #609201)

* Thu Jun 24 2010 Paul Howarth <paul@city-fan.org> - 2.30-12
- rebuild with perl 5.12.1 in Rawhide

* Fri May  7 2010 Paul Howarth <paul@city-fan.org> - 2.30-11
- fix dist tag to work with RHEL6 Beta

* Tue Feb  9 2010 Paul Howarth <paul@city-fan.org> - 2.30-10
- import from Fedora perl-TermReadKey package
- obsolete/provide perl-TermReadKey
- skip test suite, which hangs in mock
- add patches for CPAN RT#26235, CPAN RT#35669

* Fri Dec  4 2009 Stepan Kasal <skasal@redhat.com> - 2.30-9
- rebuild against perl 5.10.1

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.30-8
- rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.30-7
- rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 2.30-6
- rebuild for perl 5.10 (again)

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 2.30-5
- autorebuild for GCC 4.3

* Mon Jan 28 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 2.36-4
- rebuild for new perl

* Thu Oct 25 2007 Robin Norwood <rnorwood@redhat.com> - 2.30-3
- fix various issues from package review:
- remove extra || : from %%check
- add dist tag to release
- remove BR: perl
- fix tabs and spacing

* Tue Oct 16 2007 Tom "spot" Callaway <tcallawa@redhat.com> - 2.30-2
- correct license tag
- add BR: perl(ExtUtils::MakeMaker)

* Wed Jul 12 2006 Jesse Keating <jkeating@redhat.com> - 2.30-1.2.3
- rebuild

* Fri Feb 10 2006 Jesse Keating <jkeating@redhat.com> - 2.30-1.2.2
- bump again for double-long bug on ppc(64)

* Tue Feb 07 2006 Jesse Keating <jkeating@redhat.com> - 2.30-1.2.1
- rebuilt for new gcc4.1 snapshot and glibc changes

* Fri Feb 03 2006 Jason Vas Dias <jvdias@redhat.com> - 2.30-1.2
- rebuild for new perl-5.8.8

* Fri Dec 16 2005 Jesse Keating <jkeating@redhat.com>
- rebuilt for new gcc

* Sat Apr 02 2005 Jose Pedro Oliveira <jpo at di.uminho.pt> - 2.30-1
- update to 2.30
- spec cleanup (#153200)

* Tue Jun 15 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Tue Mar 02 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Fri Feb 13 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Tue Jun 17 2003 Chip Turner <cturner@redhat.com> - 2.20-12
- rebuild

* Mon Jan 27 2003 Chip Turner <cturner@redhat.com>
- version bump and rebuild

* Wed Nov 20 2002 Chip Turner <cturner@redhat.com>
- rebuild

* Tue Sep 10 2002 Chip Turner <cturner@redhat.com>
- remove 'make test' as it seems to open a tty and hang

* Tue Aug  6 2002 Chip Turner <cturner@redhat.com>
- automated release bump and build

* Tue Aug  6 2002 Chip Turner <cturner@redhat.com>
- update to 2.20

* Wed Jan 30 2002 cturner@redhat.com
- specfile autogenerated

